<?xml version="1.0" ?><!DOCTYPE TS><TS language="nl_NL" version="2.1">
<context>
    <name>AboutDialog</name>
    <message>
        <source>About KeePassXC</source>
        <translation>Over KeePassXC</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Over</translation>
    </message>
    <message>
        <source>Contributors</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Debug Info</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy to clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Version %1
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Revision: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Libraries:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Operating system: %1
CPU architecture: %2
Kernel: %3 %4</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enabled extensions:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Report bugs at: &lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/issues&quot; style=&quot;text-decoration: underline;&quot;&gt;https://github.com&lt;/a&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>KeePassXC is distributed under the terms of the GNU General Public License (GPL) version 2 or (at your option) version 3.</source>
        <translation>KeePassXC wordt verspreid onder de voorwaarden van de GNU General Public License (GPL) versie 2 of (als u wenst) versie 3.</translation>
    </message>
    <message>
        <source>Project Maintainers:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&lt;a href=&quot;https://github.com/keepassxreboot/keepassxc/graphs/contributors&quot;&gt;See Contributions on GitHub&lt;/a&gt;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Include the following information whenever you report a bug:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Distribution: %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>AccessControlDialog</name>
    <message>
        <source>Remember this decision</source>
        <translation>Deze keuze onthouden</translation>
    </message>
    <message>
        <source>Allow</source>
        <translation>Toestaan</translation>
    </message>
    <message>
        <source>Deny</source>
        <translation>Weigeren</translation>
    </message>
    <message>
        <source>%1 has requested access to passwords for the following item(s).
Please select whether you want to allow access.</source>
        <translation>%1 vraagt toegang tot uw wachtwoorden voor het/de volgende item(s).
Geef aan of u toegang wilt toestaan of niet.</translation>
    </message>
    <message>
        <source>KeePassXC HTTP Confirm Access</source>
        <translation>KeePassXC HTTP-toegang bevestigen</translation>
    </message>
</context>
<context>
    <name>AutoType</name>
    <message>
        <source>Couldn&apos;t find an entry that matches the window title:</source>
        <translation>Kon geen element vinden dat overeenkomt met de venstertitel:</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>Auto-typen - KeePassXC</translation>
    </message>
</context>
<context>
    <name>AutoTypeAssociationsModel</name>
    <message>
        <source>Window</source>
        <translation>Venster</translation>
    </message>
    <message>
        <source>Sequence</source>
        <translation>Volgorde</translation>
    </message>
    <message>
        <source>Default sequence</source>
        <translation>Standaardvolgorde</translation>
    </message>
</context>
<context>
    <name>AutoTypeSelectDialog</name>
    <message>
        <source>Select entry to Auto-Type:</source>
        <translation>Kies item om automatisch te typen:</translation>
    </message>
    <message>
        <source>Auto-Type - KeePassXC</source>
        <translation>Auto-typen - KeePassXC</translation>
    </message>
</context>
<context>
    <name>ChangeMasterKeyWidget</name>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Enter password:</source>
        <translation>Wachtwoord invoeren:</translation>
    </message>
    <message>
        <source>Repeat password:</source>
        <translation>Wachtwoord herhalen:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <source>Create</source>
        <translation>Creëren</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Sleutelbestanden</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Create Key File...</source>
        <translation>Sleutelbestand creëren...</translation>
    </message>
    <message>
        <source>Unable to create Key File : </source>
        <translation>Het creëren van het sleutelbestand is mislukt:</translation>
    </message>
    <message>
        <source>Select a key file</source>
        <translation>Kies een sleutelbestand</translation>
    </message>
    <message>
        <source>Do you really want to use an empty string as password?</source>
        <translation>Weet u zeker dat u een leeg veld als wachtwoord wilt gebruiken?</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>U heeft verschillende wachtwoorden opgegeven.</translation>
    </message>
    <message>
        <source>Failed to set %1 as the Key file:
%2</source>
        <translation>Het instellen van %1 als sleutelbestand is mislukt:
%2</translation>
    </message>
    <message>
        <source>&amp;Key file</source>
        <translation>&amp;Sleutelbestand</translation>
    </message>
    <message>
        <source>Cha&amp;llenge Response</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Empty password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Changing master key failed: no YubiKey inserted.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CloneDialog</name>
    <message>
        <source>Clone Options</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Replace username and password with references</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Append &apos; - Clone&apos; to title</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CsvImportWidget</name>
    <message>
        <source>Import CSV fields</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>filename</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>size, rows, columns</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Encoding</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Codec</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Text is qualified by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Fields are separated by</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Comments start with</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>First record has field names</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Number of headers line to discard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Consider &apos;\&apos; an escape character</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Preview</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Column layout</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Not present in CSV file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Empty fieldname </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>column </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Imported from CSV file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Original data: </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error(s) detected in CSV file !</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> more messages skipped]</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>CSV import: writer has errors:
</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>CsvImportWizard</name>
    <message>
        <source>Import CSV file</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
    </message>
</context>
<context>
    <name>CsvParserModel</name>
    <message>
        <source> byte, </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> rows, </source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> columns</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DatabaseOpenWidget</name>
    <message>
        <source>Enter master key</source>
        <translation>Hoofdsleutel invoeren</translation>
    </message>
    <message>
        <source>Key File:</source>
        <translation>Sleutelbestand:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Browse</source>
        <translation>Bladeren</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Niet mogelijk om de database te openen.</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Niet mogelijk om het sleutelbestand te openen</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Key files</source>
        <translation>Sleutelbestanden</translation>
    </message>
    <message>
        <source>Select key file</source>
        <translation>Kies sleutelbestand</translation>
    </message>
    <message>
        <source>Refresh</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Challenge Response:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DatabaseRepairWidget</name>
    <message>
        <source>Repair database</source>
        <translation>Database repareren</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Can&apos;t open key file</source>
        <translation>Niet mogelijk om het sleutelbestand te openen</translation>
    </message>
    <message>
        <source>Database opened fine. Nothing to do.</source>
        <translation>Database werd zonder problemen geopend. Niets te doen.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Niet mogelijk om de database te openen.</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Gelukt</translation>
    </message>
    <message>
        <source>The database has been successfully repaired
You can now save it.</source>
        <translation>De database is met succes gerepareerd
U kunt deze nu opslaan.</translation>
    </message>
    <message>
        <source>Unable to repair the database.</source>
        <translation>Niet mogelijk om de database te repareren.</translation>
    </message>
</context>
<context>
    <name>DatabaseSettingsWidget</name>
    <message>
        <source>Database name:</source>
        <translation>Naam van de database:</translation>
    </message>
    <message>
        <source>Database description:</source>
        <translation>Beschrijving van de database:</translation>
    </message>
    <message>
        <source>Transform rounds:</source>
        <translation>Transformatierondes:</translation>
    </message>
    <message>
        <source>Default username:</source>
        <translation>Standaard gebruikersnaam:</translation>
    </message>
    <message>
        <source> MiB</source>
        <translation>MiB</translation>
    </message>
    <message>
        <source>Benchmark</source>
        <translation>Test</translation>
    </message>
    <message>
        <source>Max. history items:</source>
        <translation>Max. items in geschiedenis:</translation>
    </message>
    <message>
        <source>Max. history size:</source>
        <translation>Max. geschiedenisgrootte:</translation>
    </message>
    <message>
        <source>Use recycle bin</source>
        <translation>Prullenbak gebruiken</translation>
    </message>
    <message>
        <source>AES:  256 Bit   (default)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Twofish:  256 Bit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Algorithm:</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DatabaseTabWidget</name>
    <message>
        <source>Root</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2-database</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Open database</source>
        <translation>Database openen</translation>
    </message>
    <message>
        <source>File not found!</source>
        <translation>Bestand niet gevonden!</translation>
    </message>
    <message>
        <source>Open KeePass 1 database</source>
        <translation>KeePass 1-database openen</translation>
    </message>
    <message>
        <source>KeePass 1 database</source>
        <translation>KeePass 1-database</translation>
    </message>
    <message>
        <source>All files (*)</source>
        <translation>Alle bestanden (*)</translation>
    </message>
    <message>
        <source>Close?</source>
        <translation>Sluiten?</translation>
    </message>
    <message>
        <source>Save changes?</source>
        <translation>Wijzigingen opslaan?</translation>
    </message>
    <message>
        <source>&quot;%1&quot; was modified.
Save changes?</source>
        <translation>&quot;%1&quot; is gewijzigd.
Opslaan?</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Het opslaan van de database is mislukt.</translation>
    </message>
    <message>
        <source>Save database as</source>
        <translation>Database opslaan als</translation>
    </message>
    <message>
        <source>New database</source>
        <translation>Nieuwe database</translation>
    </message>
    <message>
        <source>locked</source>
        <translation>vergrendeld</translation>
    </message>
    <message>
        <source>Lock database</source>
        <translation>Database vergrendelen</translation>
    </message>
    <message>
        <source>Can't lock the database as you are currently editing it.
Please press cancel to finish your changes or discard them.</source>
        <translation>Kan de database niet vergrendelen omdat u deze momenteel aan het bewerken bent.
Druk op annuleren om uw wijzigingen aan te passen of gooi de wijzigingen weg.</translation>
    </message>
    <message>
        <source>This database has never been saved.
You can save the database or stop locking it.</source>
        <translation>Deze database is nog niet opgeslagen.
U kunt de database opslaan of het vergrendelen annuleren.</translation>
    </message>
    <message>
        <source>This database has been modified.
Do you want to save the database before locking it?
Otherwise your changes are lost.</source>
        <translation>Deze database is gewijzigd.
Wilt u de database opslaan voordat u deze vergrendelt?
Zo nee, dan gaan de wijzigingen verloren.</translation>
    </message>
    <message>
        <source>&quot;%1&quot; is in edit mode.
Discard changes and close anyway?</source>
        <translation>&quot;%1&quot; is gewijzigd.
Wijzigingen ongedaan maken en doorgaan met sluiten?</translation>
    </message>
    <message>
        <source>Export database to CSV file</source>
        <translation>Database exporteren naar CSV-bestand</translation>
    </message>
    <message>
        <source>CSV file</source>
        <translation>CSV-bestand</translation>
    </message>
    <message>
        <source>Writing the CSV file failed.</source>
        <translation>Schrijven van het CSV-bestand mislukt.</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Het is niet mogelijk om de database te openen.</translation>
    </message>
    <message>
        <source>Merge database</source>
        <translation>Database samenvoegen</translation>
    </message>
    <message>
        <source>The database you are trying to save as is locked by another instance of KeePassXC.
Do you want to save it anyway?</source>
        <translation>De database die u op probeert te slaan is vergrendeld door een andere instantie van KeePassXC.
Wilt u toch doorgaan met opslaan?</translation>
    </message>
    <message>
        <source>Passwords</source>
        <translation>Wachtwoorden</translation>
    </message>
    <message>
        <source>Database already opened</source>
        <translation>Database is al geopend</translation>
    </message>
    <message>
        <source>The database you are trying to open is locked by another instance of KeePassXC.

Do you want to open it anyway?</source>
        <translation>De database die u probeert te openen is vergrendeld door een andere instantie van KeePassXC.
Wilt u toch doorgaan met openen?</translation>
    </message>
    <message>
        <source>Open read-only</source>
        <translation>Openen als alleen-lezen</translation>
    </message>
    <message>
        <source>File opened in read only mode.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open CSV file</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>DatabaseWidget</name>
    <message>
        <source>Change master key</source>
        <translation>Wijzig hoofdsleutel</translation>
    </message>
    <message>
        <source>Delete entry?</source>
        <translation>Element verwijderen?</translation>
    </message>
    <message>
        <source>Do you really want to delete the entry &quot;%1&quot; for good?</source>
        <translation>Weet u zeker dat u het element &quot;%1&quot; wilt verwijderen?</translation>
    </message>
    <message>
        <source>Delete entries?</source>
        <translation>Elementen wissen?</translation>
    </message>
    <message>
        <source>Do you really want to delete %1 entries for good?</source>
        <translation>Weet u zeker dat u %1 elementen wilt wissen?</translation>
    </message>
    <message>
        <source>Move entries to recycle bin?</source>
        <translation>Elementen naar de prullenbak verplaatsen?</translation>
    </message>
    <message numerus="yes">
        <source>Do you really want to move %n entry(s) to the recycle bin?</source>
        <translation><numerusform>Weet u zeker dat u %n element naar de prullenbak wilt verplaatsen?</numerusform><numerusform>Weet u zeker dat u %n elementen naar de prullenbak wilt verplaatsen?</numerusform></translation>
    </message>
    <message>
        <source>Delete group?</source>
        <translation>Groep verwijderen?</translation>
    </message>
    <message>
        <source>Do you really want to delete the group &quot;%1&quot; for good?</source>
        <translation>Weet u zeker dat u de groep &quot;%1&quot; wilt verwijderen?</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
    </message>
    <message>
        <source>Move entry to recycle bin?</source>
        <translation>Wilt u het item naar de prullenbak verplaatsen?</translation>
    </message>
    <message>
        <source>Do you really want to move entry &quot;%1&quot; to the recycle bin?</source>
        <translation>Weet u zeker dat u item &quot;%1&quot; naar de prullenbak wilt verplaatsen?</translation>
    </message>
    <message>
        <source>Searching...</source>
        <translation>Bezig met zoeken...</translation>
    </message>
    <message>
        <source>No current database.</source>
        <translation>Geen huidige database.</translation>
    </message>
    <message>
        <source>No source database, nothing to do.</source>
        <translation>Geen brondatabase; er valt niks te doen.</translation>
    </message>
    <message>
        <source>Search Results (%1)</source>
        <translation>Zoekresultaten (%1)</translation>
    </message>
    <message>
        <source>No Results</source>
        <translation>Geen resultaten</translation>
    </message>
    <message>
        <source>Execute command?</source>
        <translation>Commando uitvoeren?</translation>
    </message>
    <message>
        <source>Do you really want to execute the following command?&lt;br&gt;&lt;br&gt;%1&lt;br&gt;</source>
        <translation>Weet u zeker dat u het volgende commando wilt uitvoeren? &lt;br&gt;&lt;br&gt;%1&lt;br&gt;</translation>
    </message>
    <message>
        <source>Remember my choice</source>
        <translation>Mijn keuze onthouden</translation>
    </message>
    <message>
        <source>Autoreload Request</source>
        <translation>Automatisch herladen-verzoeken</translation>
    </message>
    <message>
        <source>The database file has changed. Do you want to load the changes?</source>
        <translation>Het database-bestand is gewijzigd. Wilt u de wijzigingen laden?</translation>
    </message>
    <message>
        <source>Merge Request</source>
        <translation>Samenvoegingsverzoek</translation>
    </message>
    <message>
        <source>The database file has changed and you have unsaved changes.Do you want to merge your changes?</source>
        <translation>Het database-bestand is gewijzigd en u heeft niet-opgeslagen wijzigingen. Wilt u uw wijzigingen samenvoegen?</translation>
    </message>
    <message>
        <source>Could not open the new database file while attempting to autoreload this database.</source>
        <translation>De nieuwe database kan niet worden geopend tijdens het automatisch herladen van deze database.</translation>
    </message>
    <message>
        <source>Empty recycle bin?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to permanently delete everything from your recycle bin?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EditEntryWidget</name>
    <message>
        <source>Entry</source>
        <translation>Element</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icoon</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto-typen - KeePassX</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>History</source>
        <translation>Geschiedenis</translation>
    </message>
    <message>
        <source>Entry history</source>
        <translation>Geschiedenis van element</translation>
    </message>
    <message>
        <source>Add entry</source>
        <translation>Element toevoegen</translation>
    </message>
    <message>
        <source>Edit entry</source>
        <translation>Element wijzigen</translation>
    </message>
    <message>
        <source>Different passwords supplied.</source>
        <translation>Verschillende wachtwoorden opgegeven.</translation>
    </message>
    <message>
        <source>New attribute</source>
        <translation>Nieuwe eigenschap</translation>
    </message>
    <message>
        <source>Select file</source>
        <translation>Kies bestand</translation>
    </message>
    <message>
        <source>Unable to open file</source>
        <translation>Niet mogelijk om bestand te openen</translation>
    </message>
    <message>
        <source>Save attachment</source>
        <translation>Bijlage opslaan</translation>
    </message>
    <message>
        <source>Unable to save the attachment:
</source>
        <translation>Niet mogelijk om de bijlage op te slaan:
</translation>
    </message>
    <message>
        <source>Tomorrow</source>
        <translation>Morgen</translation>
    </message>
    <message numerus="yes">
        <source>%n week(s)</source>
        <translation><numerusform>%n week</numerusform><numerusform>%n weken</numerusform></translation>
    </message>
    <message numerus="yes">
        <source>%n month(s)</source>
        <translation><numerusform>%n maand</numerusform><numerusform>%n maanden</numerusform></translation>
    </message>
    <message>
        <source>1 year</source>
        <translation>1 jaar</translation>
    </message>
    <message>
        <source>Confirm Remove</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to remove this attribute?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>[PROTECTED] Press reveal to view or edit</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Are you sure you want to remove this attachment?</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EditEntryWidgetAdvanced</name>
    <message>
        <source>Additional attributes</source>
        <translation>Extra eigenschappen</translation>
    </message>
    <message>
        <source>Add</source>
        <translation>Toevoegen</translation>
    </message>
    <message>
        <source>Remove</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Attachments</source>
        <translation>Bijlagen</translation>
    </message>
    <message>
        <source>Save</source>
        <translation>Opslaan</translation>
    </message>
    <message>
        <source>Open</source>
        <translation>Open</translation>
    </message>
    <message>
        <source>Edit Name</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Protect</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Reveal</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EditEntryWidgetAutoType</name>
    <message>
        <source>Enable Auto-Type for this entry</source>
        <translation>Auto-typen inschakelen voor dit element</translation>
    </message>
    <message>
        <source>+</source>
        <translation>+</translation>
    </message>
    <message>
        <source>-</source>
        <translation>-</translation>
    </message>
    <message>
        <source>Window title:</source>
        <translation>Venstertitel:</translation>
    </message>
    <message>
        <source>Inherit default Auto-Type sequence from the &amp;group</source>
        <translation>Erf standaard auto-typevolgorde van de &amp;groep</translation>
    </message>
    <message>
        <source>&amp;Use custom Auto-Type sequence:</source>
        <translation>&amp;Gebruik aangepaste auto-typevolgorde:</translation>
    </message>
    <message>
        <source>Use default se&amp;quence</source>
        <translation>Gebruik standaardvolgorde</translation>
    </message>
    <message>
        <source>Set custo&amp;m sequence:</source>
        <translation>Stel aangepaste volgorde in:</translation>
    </message>
    <message>
        <source>Window Associations</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EditEntryWidgetHistory</name>
    <message>
        <source>Show</source>
        <translation>Tonen</translation>
    </message>
    <message>
        <source>Restore</source>
        <translation>Herstellen</translation>
    </message>
    <message>
        <source>Delete</source>
        <translation>Verwijderen</translation>
    </message>
    <message>
        <source>Delete all</source>
        <translation>Alles verwijderen</translation>
    </message>
</context>
<context>
    <name>EditEntryWidgetMain</name>
    <message>
        <source>Title:</source>
        <translation>Titel:</translation>
    </message>
    <message>
        <source>Username:</source>
        <translation>Gebruikersnaam:</translation>
    </message>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Repeat:</source>
        <translation>Herhalen:</translation>
    </message>
    <message>
        <source>URL:</source>
        <translation>URL:</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Verloopt</translation>
    </message>
    <message>
        <source>Presets</source>
        <translation>Ingebouwd</translation>
    </message>
    <message>
        <source>Notes:</source>
        <translation>Opmerkingen:</translation>
    </message>
</context>
<context>
    <name>EditGroupWidget</name>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Icon</source>
        <translation>Icoon</translation>
    </message>
    <message>
        <source>Properties</source>
        <translation>Eigenschappen</translation>
    </message>
    <message>
        <source>Add group</source>
        <translation>Groep toevoegen</translation>
    </message>
    <message>
        <source>Edit group</source>
        <translation>Groep wijzigen</translation>
    </message>
    <message>
        <source>Enable</source>
        <translation>Inschakelen</translation>
    </message>
    <message>
        <source>Disable</source>
        <translation>Uitschakelen</translation>
    </message>
    <message>
        <source>Inherit from parent group (%1)</source>
        <translation>Erf van bovenliggende groep (%1)</translation>
    </message>
</context>
<context>
    <name>EditGroupWidgetMain</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Opmerkingen</translation>
    </message>
    <message>
        <source>Expires</source>
        <translation>Verloopt</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto-typen - KeePassX</translation>
    </message>
    <message>
        <source>&amp;Use default Auto-Type sequence of parent group</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set default Auto-Type se&amp;quence</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EditWidgetIcons</name>
    <message>
        <source>Add custom icon</source>
        <translation>Voeg icoon toe</translation>
    </message>
    <message>
        <source>Delete custom icon</source>
        <translation>Verwijder icoon</translation>
    </message>
    <message>
        <source>Images</source>
        <translation>Afbeeldingen</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Select Image</source>
        <translation>Kies afbeelding</translation>
    </message>
    <message>
        <source>Download favicon</source>
        <translation>Favicon downloaden</translation>
    </message>
    <message>
        <source>Unable to fetch favicon.</source>
        <translation>Favicon kan niet worden opgehaald.</translation>
    </message>
    <message>
        <source>Can&apos;t read icon</source>
        <translation>Kan icoon niet lezen</translation>
    </message>
    <message>
        <source>&amp;Use default icon</source>
        <translation>&amp;Gebruik standaardicoon</translation>
    </message>
    <message>
        <source>Use custo&amp;m icon</source>
        <translation>Gebruik aangepast icoon</translation>
    </message>
    <message>
        <source>Confirm Delete</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>This icon is used by %1 entries, and will be replaced by the default icon. Are you sure you want to delete it?</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Hint: You can enable Google as a fallback under Tools&gt;Settings&gt;Security</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Custom icon already exists</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>EditWidgetProperties</name>
    <message>
        <source>Created:</source>
        <translation>Aangemaakt:</translation>
    </message>
    <message>
        <source>Modified:</source>
        <translation>Gewijzigd:</translation>
    </message>
    <message>
        <source>Accessed:</source>
        <translation>Gelezen:</translation>
    </message>
    <message>
        <source>Uuid:</source>
        <translation>Uuid:</translation>
    </message>
</context>
<context>
    <name>Entry</name>
    <message>
        <source> - Clone</source>
        <translation>- Kloon</translation>
    </message>
</context>
<context>
    <name>EntryAttributesModel</name>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
</context>
<context>
    <name>EntryHistoryModel</name>
    <message>
        <source>Last modified</source>
        <translation>Laatst gewijzigd</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
</context>
<context>
    <name>EntryModel</name>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Ref: </source>
        <comment>Reference abbreviation</comment>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Group</name>
    <message>
        <source>Recycle Bin</source>
        <translation>Prullenbak</translation>
    </message>
</context>
<context>
    <name>HttpPasswordGeneratorWidget</name>
    <message>
        <source>Length:</source>
        <translation>Lengte:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Tekens</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Hoofdletters</translation>
    </message>
    <message>
        <source>A-Z</source>
        <translation>A-Z</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Kleine letters</translation>
    </message>
    <message>
        <source>a-z</source>
        <translation>a-z</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Cijfers</translation>
    </message>
    <message>
        <source>0-9</source>
        <translation>0-9</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Speciale tekens</translation>
    </message>
    <message>
        <source>/*_&amp; ...</source>
        <translation>/*_&amp; ...</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Sluit op elkaar lijkende tekens uit</translation>
    </message>
    <message>
        <source>Ensure that the password contains characters from every group</source>
        <translation>Zorg ervoor dat het wachtwoord tekens uit iedere groep bevat</translation>
    </message>
</context>
<context>
    <name>KMessageWidget</name>
    <message>
        <source>&amp;Close</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Close message</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>KeePass1OpenWidget</name>
    <message>
        <source>Import KeePass1 database</source>
        <translation>Importeer Keepass 1-database</translation>
    </message>
    <message>
        <source>Unable to open the database.</source>
        <translation>Niet mogelijk om de database te openen.</translation>
    </message>
</context>
<context>
    <name>KeePass1Reader</name>
    <message>
        <source>Unable to read keyfile.</source>
        <translation>Niet mogelijk om sleutelbestand te lezen</translation>
    </message>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Geen Keepass-database</translation>
    </message>
    <message>
        <source>Unsupported encryption algorithm.</source>
        <translation>Niet-ondersteund encryptie-algoritme</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Niet-ondersteunde versie van Keepass-database</translation>
    </message>
    <message>
        <source>Root</source>
        <translation>Alles</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Verkeerde sleutel of corrupte database.</translation>
    </message>
</context>
<context>
    <name>KeePass2Reader</name>
    <message>
        <source>Not a KeePass database.</source>
        <translation>Geen Keepass-database.</translation>
    </message>
    <message>
        <source>Unsupported KeePass database version.</source>
        <translation>Niet-ondersteunde versie van Keepass-database.</translation>
    </message>
    <message>
        <source>Wrong key or database file is corrupt.</source>
        <translation>Verkeerde sleutel of corrupte database.</translation>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
    </message>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The selected file is an old KeePass 1 database (.kdb).

You can import it by clicking on Database &gt; 'Import KeePass 1 database...'.
This is a one-way migration. You won&apos;t be able to open the imported database with the old KeePassX 0.4 version.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>KeePass2Writer</name>
    <message>
        <source>Unable to issue challenge-response.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to calculate master key</source>
        <translation>Niet mogelijk om hoofdsleutel te berekenen</translation>
    </message>
</context>
<context>
    <name>Main</name>
    <message>
        <source>Fatal error while testing the cryptographic functions.</source>
        <translation>Fatale fout bij het testen van de cryptografische functies.</translation>
    </message>
    <message>
        <source>KeePassXC - Error</source>
        <translation>KeePassX - Fout</translation>
    </message>
    <message>
        <source>The lock file could not be created. Single-instance mode disabled.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Another instance of KeePassXC is already running.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Existing single-instance lock file is invalid. Launching new instance.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>MainWindow</name>
    <message>
        <source>Open database</source>
        <translation>Open database</translation>
    </message>
    <message>
        <source>Database settings</source>
        <translation>Database-instellingen</translation>
    </message>
    <message>
        <source>Copy username to clipboard</source>
        <translation>Kopieer gebruikersnaam naar klembord</translation>
    </message>
    <message>
        <source>Copy password to clipboard</source>
        <translation>Kopieer wachtwoord naar klembord</translation>
    </message>
    <message>
        <source>Settings</source>
        <translation>Instellingen</translation>
    </message>
    <message>
        <source>Show toolbar</source>
        <translation>Werkbalk weergeven</translation>
    </message>
    <message>
        <source>read-only</source>
        <translation>alleen-lezen</translation>
    </message>
    <message>
        <source>Toggle window</source>
        <translation>Wissel venster</translation>
    </message>
    <message>
        <source>KeePass 2 Database</source>
        <translation>KeePass 2 Database</translation>
    </message>
    <message>
        <source>All files</source>
        <translation>Alle bestanden</translation>
    </message>
    <message>
        <source>Save repaired database</source>
        <translation>Gerepareerde database opslaan</translation>
    </message>
    <message>
        <source>Writing the database failed.</source>
        <translation>Opslaan van de database is mislukt.</translation>
    </message>
    <message>
        <source>&amp;Recent databases</source>
        <translation>&amp;Recente databases</translation>
    </message>
    <message>
        <source>E&amp;ntries</source>
        <translation>Items</translation>
    </message>
    <message>
        <source>Copy att&amp;ribute to clipboard</source>
        <translation>Kopieer eigenschap naar klembord</translation>
    </message>
    <message>
        <source>&amp;Groups</source>
        <translation>&amp;Groepen</translation>
    </message>
    <message>
        <source>&amp;View</source>
        <translation>&amp;Beeld</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Over</translation>
    </message>
    <message>
        <source>&amp;Save database</source>
        <translation>&amp;Sla database op</translation>
    </message>
    <message>
        <source>&amp;Close database</source>
        <translation>&amp;Sluit database</translation>
    </message>
    <message>
        <source>&amp;New database</source>
        <translation>&amp;Nieuwe database</translation>
    </message>
    <message>
        <source>Merge from KeePassX database</source>
        <translation>KeePassX database samenvoegen</translation>
    </message>
    <message>
        <source>&amp;Add new entry</source>
        <translation>&amp;Voeg nieuw item toe</translation>
    </message>
    <message>
        <source>&amp;View/Edit entry</source>
        <translation>&amp;Bekijk/bewerk item</translation>
    </message>
    <message>
        <source>&amp;Delete entry</source>
        <translation>&amp;Verwijder item</translation>
    </message>
    <message>
        <source>&amp;Add new group</source>
        <translation>&amp;Voeg groep toe</translation>
    </message>
    <message>
        <source>&amp;Edit group</source>
        <translation>&amp;Bewerk groep</translation>
    </message>
    <message>
        <source>&amp;Delete group</source>
        <translation>&amp;Verwijder groep</translation>
    </message>
    <message>
        <source>&amp;Database settings</source>
        <translation>&amp;Database-instellingen</translation>
    </message>
    <message>
        <source>&amp;Clone entry</source>
        <translation>&amp;Kloon item</translation>
    </message>
    <message>
        <source>Timed one-time password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy &amp;TOTP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show TOTP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Find</source>
        <translation>&amp;Zoeken</translation>
    </message>
    <message>
        <source>Copy &amp;username</source>
        <translation>Kopieer &amp;gebruikersnaam</translation>
    </message>
    <message>
        <source>Cop&amp;y password</source>
        <translation>Kopieer wachtwoord</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>&amp;Perform Auto-Type</source>
        <translation>&amp;Voer auto-typen uit</translation>
    </message>
    <message>
        <source>&amp;Open URL</source>
        <translation>&amp;Open URL</translation>
    </message>
    <message>
        <source>&amp;Lock databases</source>
        <translation>&amp;Vergrendel databases</translation>
    </message>
    <message>
        <source>&amp;Title</source>
        <translation>&amp;Titel</translation>
    </message>
    <message>
        <source>&amp;URL</source>
        <translation>&amp;URL</translation>
    </message>
    <message>
        <source>&amp;Notes</source>
        <translation>&amp;Opmerkingen</translation>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>Wachtwoord generator</translation>
    </message>
    <message>
        <source>Clear history</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Tools</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Empty recycle bin</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Quit KeePassXC</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Please touch the button on your YubiKey!</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Open database...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Sa&amp;ve database as...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Change &amp;master key...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Export to CSV file...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import KeePass 1 database...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import CSV file...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Re&amp;pair database...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Set up TOTP...</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>OptionDialog</name>
    <message>
        <source>Dialog</source>
        <translation>Dialoog</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>Sh&amp;ow a notification when credentials are requested</source>
        <translation>Toon een notificatie wanneer inloggegevens worden aangevraagd</translation>
    </message>
    <message>
        <source>Sort matching entries by &amp;username</source>
        <translation>Sorteer gegeven items op $gebruikersnaam</translation>
    </message>
    <message>
        <source>Re&amp;move all stored permissions from entries in active database</source>
        <translation>Verwijder alle opgeslagen permissies van items uit de actieve database</translation>
    </message>
    <message>
        <source>Advanced</source>
        <translation>Geavanceerd</translation>
    </message>
    <message>
        <source>Always allow &amp;access to entries</source>
        <translation>Altijd &amp;toegang verlenen tot items</translation>
    </message>
    <message>
        <source>Always allow &amp;updating entries</source>
        <translation>Altijd &amp;bewerken toestaan op items</translation>
    </message>
    <message>
        <source>Searc&amp;h in all opened databases for matching entries</source>
        <translation>Zoek in alle geopende databases naar overeenkomende items</translation>
    </message>
    <message>
        <source>HTTP Port:</source>
        <translation>HTTP-poort:</translation>
    </message>
    <message>
        <source>Default port: 19455</source>
        <translation>Standaard poort: 19455</translation>
    </message>
    <message>
        <source>Re&amp;quest to unlock the database if it is locked</source>
        <translation>Verzoek om database te ontgrendelen als deze vergrendeld is</translation>
    </message>
    <message>
        <source>Sort &amp;matching entries by title</source>
        <translation>Sorteer &amp;overeenkomende items op titel</translation>
    </message>
    <message>
        <source>KeePassXC will listen to this port on 127.0.0.1</source>
        <translation>KeePassXC zal op deze poort op 127.0.0.1 luisteren</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports</source>
        <translation>Kan niet binden op bevoorrechte poorten</translation>
    </message>
    <message>
        <source>Cannot bind to privileged ports below 1024!
Using default port 19455.</source>
        <translation>Kan niet binden naar bevoorrechte poorten onder 1024!
Standaardpoort 19455 wordt gebruikt.</translation>
    </message>
    <message>
        <source>R&amp;emove all shared encryption keys from active database</source>
        <translation>Verwijder alle gedeelde encryptiesleutels uit de actieve database</translation>
    </message>
    <message>
        <source>&amp;Return advanced string fields which start with &quot;KPH: &quot;</source>
        <translation>&amp;Geef geadvanceerde tekenreeks velden terug die met &quot;KH: &quot; beginnen.</translation>
    </message>
    <message>
        <source>Automatically creating or updating string fields is not supported.</source>
        <translation>Het automatisch aanmaken of wijzigen van tekenreeks velden wordt niet ondersteund.</translation>
    </message>
    <message>
        <source>This is required for accessing your databases from ChromeIPass or PassIFox</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable KeePassHTTP server</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only returns the best matches for a specific URL instead of all entries for the whole domain.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Return only best matching entries</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Only entries with the same scheme (http://, https://, ftp://, ...) are returned.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&amp;Match URL schemes</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password Generator</source>
        <translation>Wachtwoord generator</translation>
    </message>
    <message>
        <source>Only the selected database has to be connected with a client.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The following options can be dangerous!
Change them only if you know what you are doing.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>PasswordGeneratorWidget</name>
    <message>
        <source>Password:</source>
        <translation>Wachtwoord:</translation>
    </message>
    <message>
        <source>Character Types</source>
        <translation>Tekens</translation>
    </message>
    <message>
        <source>Upper Case Letters</source>
        <translation>Hoofdletters</translation>
    </message>
    <message>
        <source>Lower Case Letters</source>
        <translation>Kleine letters</translation>
    </message>
    <message>
        <source>Numbers</source>
        <translation>Cijfers</translation>
    </message>
    <message>
        <source>Special Characters</source>
        <translation>Speciale tekens</translation>
    </message>
    <message>
        <source>Exclude look-alike characters</source>
        <translation>Geen op elkaar lijkende tekens</translation>
    </message>
    <message>
        <source>Accept</source>
        <translation>Accepteren</translation>
    </message>
    <message>
        <source>%p%</source>
        <translation>%p%</translation>
    </message>
    <message>
        <source>strength</source>
        <translation>sterkte</translation>
    </message>
    <message>
        <source>entropy</source>
        <translation>entropie</translation>
    </message>
    <message>
        <source>&amp;Length:</source>
        <translation>&amp;Lengte:</translation>
    </message>
    <message>
        <source>Pick characters from every group</source>
        <translation>Zorg dat het wachtwoord tekens uit iedere groep bevat</translation>
    </message>
    <message>
        <source>Generate</source>
        <translation>Genereren</translation>
    </message>
    <message>
        <source>Close</source>
        <translation>Sluiten</translation>
    </message>
    <message>
        <source>Apply</source>
        <translation>Toepassen</translation>
    </message>
    <message>
        <source>Entropy: %1 bit</source>
        <translation>Entropie: %1 bit</translation>
    </message>
    <message>
        <source>Password Quality: %1</source>
        <translation>Wachtwoord kwaliteit: %1</translation>
    </message>
    <message>
        <source>Poor</source>
        <translation>Slecht</translation>
    </message>
    <message>
        <source>Weak</source>
        <translation>Zwak</translation>
    </message>
    <message>
        <source>Good</source>
        <translation>Goed</translation>
    </message>
    <message>
        <source>Excellent</source>
        <translation>Uitstekend</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>Extended ASCII</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Passphrase</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Wordlist:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Word Count:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Word Separator:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>NULL device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>error reading from device</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>file empty !
</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>malformed string</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>missing closing quote</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>INTERNAL - unget lower bound exceeded</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Group</source>
        <translation>Groep</translation>
    </message>
    <message>
        <source>Title</source>
        <translation>Titel</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Gebruikersnaam</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Wachtwoord</translation>
    </message>
    <message>
        <source>URL</source>
        <translation>URL</translation>
    </message>
    <message>
        <source>Notes</source>
        <translation>Opmerkingen</translation>
    </message>
    <message>
        <source>Browser Integration</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>YubiKey[%1] Challenge Response - Slot %2 - %3</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Press</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Passive</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>QtIOCompressor</name>
    <message>
        <source>Internal zlib error when compressing: </source>
        <translation>Interne fout in zlib bij inpakken:</translation>
    </message>
    <message>
        <source>Error writing to underlying device: </source>
        <translation>Fout bij schrijven naar onderliggend apparaat:</translation>
    </message>
    <message>
        <source>Error opening underlying device: </source>
        <translation>Fout bij openen van onderliggend apparaat:</translation>
    </message>
    <message>
        <source>Error reading data from underlying device: </source>
        <translation>Fout bij lezen van gegevens van onderliggend apparaat:</translation>
    </message>
    <message>
        <source>Internal zlib error when decompressing: </source>
        <translation>Interne fout in zlib bij uitpakken:</translation>
    </message>
</context>
<context>
    <name>QtIOCompressor::open</name>
    <message>
        <source>The gzip format not supported in this version of zlib.</source>
        <translation>Gzip wordt niet ondersteund in deze versie van zlib.</translation>
    </message>
    <message>
        <source>Internal zlib error: </source>
        <translation>Interne fout in zlib:</translation>
    </message>
</context>
<context>
    <name>SearchWidget</name>
    <message>
        <source>Case Sensitive</source>
        <translation>Hoofdlettergevoelig</translation>
    </message>
    <message>
        <source>Search</source>
        <translation>Zoeken</translation>
    </message>
    <message>
        <source>Clear</source>
        <translation>Wissen</translation>
    </message>
    <message>
        <source>Search...</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Limit search to selected group</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>Service</name>
    <message>
        <source>A shared encryption-key with the name &quot;%1&quot; already exists.
Do you want to overwrite it?</source>
        <translation>Een gedeelde encryptiesleutel met de naam &quot;%1&quot; bestaat al.
Wil je deze overschrjiven?</translation>
    </message>
    <message>
        <source>Do you want to update the information in %1 - %2?</source>
        <translation>Wil je de gegevens in %1 - %2 bijwerken?</translation>
    </message>
    <message>
        <source>The active database is locked!
Please unlock the selected database or choose another one which is unlocked.</source>
        <translation>De actieve database is vergrendeld!
Ontgrendel de geselecteerde database of kies een ontgrendelde database.</translation>
    </message>
    <message>
        <source>Successfully removed %1 encryption-%2 from KeePassX/Http Settings.</source>
        <translation>%1 encryptie%2 succesvol verwijderd uit de KeePassX/Http instellingen.</translation>
    </message>
    <message>
        <source>No shared encryption-keys found in KeePassHttp Settings.</source>
        <translation>Geen gedeelde encryptiesleutels gevonen in de KeePassHttp instellingen.</translation>
    </message>
    <message>
        <source>The active database does not contain an entry of KeePassHttp Settings.</source>
        <translation>De actieve database bevat geen KeePassHttp instellingen.</translation>
    </message>
    <message>
        <source>Removing stored permissions...</source>
        <translation>Opgeslagen permissies verwijderen...</translation>
    </message>
    <message>
        <source>Abort</source>
        <translation>Afbreken</translation>
    </message>
    <message>
        <source>Successfully removed permissions from %1 %2.</source>
        <translation>De permissies zijn met succes verwijderd uit %1 %2.</translation>
    </message>
    <message>
        <source>The active database does not contain an entry with permissions.</source>
        <translation>De actieve database bevat geen items met permissies.</translation>
    </message>
    <message>
        <source>KeePassXC: New key association request</source>
        <translation>KeePassXC: Nieuw verzoek voor sleutel associatie</translation>
    </message>
    <message>
        <source>You have received an association request for the above key.
If you would like to allow it access to your KeePassXC database
give it a unique name to identify and accept it.</source>
        <translation>Je hebt verzoek voor sleutel associatie ontvangen voor de bovenstaande sleutel.
Geef het een unieke identificerende naam en accepteer de associate wanneer je deze toestaan voor toegang tot je KeePassXC database.</translation>
    </message>
    <message>
        <source>KeePassXC: Overwrite existing key?</source>
        <translation>KeePassXC: Huidige sleutel overschrijven?</translation>
    </message>
    <message>
        <source>KeePassXC: Update Entry</source>
        <translation>KeePassXC: Item bijwerken</translation>
    </message>
    <message>
        <source>KeePassXC: Database locked!</source>
        <translation>KeePassXC: Database vergrendeld!</translation>
    </message>
    <message>
        <source>KeePassXC: Removed keys from database</source>
        <translation>KeePassXC: Sleutels uit database verwijderd</translation>
    </message>
    <message>
        <source>KeePassXC: No keys found</source>
        <translation>KeePassXC: Geen sleutels gevonden</translation>
    </message>
    <message>
        <source>KeePassXC: Settings not available!</source>
        <translation>KeePassXC: Instellingen niet beschikbaar!</translation>
    </message>
    <message>
        <source>KeePassXC: Removed permissions</source>
        <translation>KeePassXC: Permissies verwijderd</translation>
    </message>
    <message>
        <source>KeePassXC: No entry with permissions found!</source>
        <translation>KeePassXC: Geen item met permissies gevonden!</translation>
    </message>
</context>
<context>
    <name>SettingsWidget</name>
    <message>
        <source>Application Settings</source>
        <translation>Programma-instellingen</translation>
    </message>
    <message>
        <source>General</source>
        <translation>Algemeen</translation>
    </message>
    <message>
        <source>Security</source>
        <translation>Beveiliging</translation>
    </message>
    <message>
        <source>Access error for config file %1</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SettingsWidgetGeneral</name>
    <message>
        <source>Remember last databases</source>
        <translation>Onthoud laatste databases</translation>
    </message>
    <message>
        <source>Automatically save on exit</source>
        <translation>Automatisch opslaan bij afsluiten</translation>
    </message>
    <message>
        <source>Automatically save after every change</source>
        <translation>Automatisch opslaan na iedere wijziging</translation>
    </message>
    <message>
        <source>Minimize when copying to clipboard</source>
        <translation>Minimaliseer bij kopiëren naar klembord</translation>
    </message>
    <message>
        <source>Use group icon on entry creation</source>
        <translation>Gebruik icoon van de groep voor nieuwe elementen</translation>
    </message>
    <message>
        <source>Global Auto-Type shortcut</source>
        <translation>Globale sneltoets voor auto-typen</translation>
    </message>
    <message>
        <source>Language</source>
        <translation>Taal</translation>
    </message>
    <message>
        <source>Show a system tray icon</source>
        <translation>Toon een icoon in de systray</translation>
    </message>
    <message>
        <source>Hide window to system tray when minimized</source>
        <translation>Bij minimaliseren enkel icoon in systray tonen</translation>
    </message>
    <message>
        <source>Load previous databases on startup</source>
        <translation>Open vorige databases bij starten</translation>
    </message>
    <message>
        <source>Automatically reload the database when modified externally</source>
        <translation>Herlaad database automatisch als deze van buitenaf is gewijzigd</translation>
    </message>
    <message>
        <source>Hide window to system tray instead of app exit</source>
        <translation>Bij sluiten icoon in systray tonen in plaats van volledig afsluiten</translation>
    </message>
    <message>
        <source>Minimize window at application startup</source>
        <translation>Scherm minimaliseren bij het opstarten</translation>
    </message>
    <message>
        <source>Basic Settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Remember last key files and security dongles</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Don&apos;t mark database as modified for non-data changes (e.g., expanding groups)</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto-Type</source>
        <translation>Auto-typen - KeePassX</translation>
    </message>
    <message>
        <source>Use entry title and URL to match windows for global Auto-Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Always ask before performing Auto-Type</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Auto-Type delay</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> ms</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start only a single instance of KeePassXC</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SettingsWidgetSecurity</name>
    <message>
        <source>Clear clipboard after</source>
        <translation>Leeg klembord na</translation>
    </message>
    <message>
        <source> sec</source>
        <translation>sec</translation>
    </message>
    <message>
        <source>Lock databases after inactivity of</source>
        <translation>Vergrendel databases na inactiviteit van</translation>
    </message>
    <message>
        <source>Show passwords in cleartext by default</source>
        <translation>Laat wachtwoorden standaard zien</translation>
    </message>
    <message>
        <source>Lock databases after minimizing the window</source>
        <translation>Vergrendel databases na het minimaliseren van het scherm</translation>
    </message>
    <message>
        <source>Don&apos;t require password repeat when it is visible</source>
        <translation>Herhalen van wachtwoord niet vereisen als deze zichtbaar is</translation>
    </message>
    <message>
        <source>Timeouts</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Convenience</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Lock databases when session is locked or lid is closed</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Privacy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use Google as fallback for downloading website icons</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>SetupTotpDialog</name>
    <message>
        <source>Setup TOTP</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Key:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use custom settings</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Note: Change these settings only if you know what you are doing.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Time step:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>8 digits</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>6 digits</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Code size:</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source> sec</source>
        <translation>sec</translation>
    </message>
</context>
<context>
    <name>TotpDialog</name>
    <message>
        <source>Timed Password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>000000</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Copy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Expires in</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>seconds</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>UnlockDatabaseWidget</name>
    <message>
        <source>Unlock database</source>
        <translation>Database ontgrendelen</translation>
    </message>
</context>
<context>
    <name>WelcomeWidget</name>
    <message>
        <source>Welcome to KeePassXC</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Start storing your passwords securely in a KeePassXC database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Create new database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Open existing database</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import from KeePass 1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Import from CSV</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Recent databases</source>
        <translation>Recente databases</translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>path to a custom config file</source>
        <translation>pad naar een configuratiebestand</translation>
    </message>
    <message>
        <source>key file of the database</source>
        <translation>sleutelbestand van de database</translation>
    </message>
    <message>
        <source>KeePassXC - cross-platform password manager</source>
        <translation>KeepassX - multi-platform wachtwoordbeheerder</translation>
    </message>
    <message>
        <source>read password of the database from stdin</source>
        <translation>lees wachtwoord van de database uit stdin</translation>
    </message>
    <message>
        <source>filenames of the password databases to open (*.kdbx)</source>
        <translation>bestandsnamen van de te openen wachtwoorddatabases (*.kdbx)</translation>
    </message>
    <message>
        <source>Copy a password to the clipboard</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path of the database.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use a GUI prompt unlocking the database.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name of the entry to clip.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Extract and print the content of a database.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path of the database to extract.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name of the command to execute.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>List database entries.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path of the group to list. Default is /</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Print the UUIDs of the entries and groups.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Merge two databases.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path of the database to merge into.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Path of the database to merge from.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Use the same password for both database files.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Show a password.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Name of the entry to show.</source>
        <translation type="unfinished"/>
    </message>
</context>
</TS>